\name{mdeleCov}
\alias{mdeleCov}
\title{Estimate the covariance matrix of the MDELE}
\description{
  Estimate the covariance matrix of the maximum dual empirical
  likelihood estimator (MDELE).
}
\usage{
mdeleCov(drmfit)
}
\arguments{
  \item{drmfit}{a fitted DRM object (an output from the
    \code{\link{drmdel}} function). See \code{\link{drmdel}} for
    details.}
}
\value{
  The estimated covariance matrix of the MDELE.
}
\examples{
# Data generation
set.seed(25)
n_samples <- c(100, 200, 180, 150, 175)  # sample sizes
x0 <- rgamma(n_samples[1], shape=5, rate=1.8)
x1 <- rgamma(n_samples[2], shape=12, rate=1.2)
x2 <- rgamma(n_samples[3], shape=12, rate=1.2)
x3 <- rgamma(n_samples[4], shape=18, rate=5)
x4 <- rgamma(n_samples[5], shape=25, rate=2.6)
x <- c(x0, x1, x2, x3, x4)

# Fit a DRM with the basis function q(x) = (x, log(abs(x))), which
# is the basis function for gamma family. This basis function is
# the built-in basis function 6.
drmfit <- drmdel(x=x, n_samples=n_samples, basis_func=6)

# Check MDELE
drmfit$mdele

# Estimate the covariance matrix of the MDELE
mdeleCov(drmfit)
}
